==> examples-0.0.3.tgz: package/src/CombinedValidations.tsx <==
import * as React from 'react';
import { Formik, Field, Form, ErrorMessage } from 'formik';
import * as Yup from 'yup';
import Debug from './Debug';

const Schema = Yup.object().shape({
  email: Yup.string().required('This field is required'),
});

// Async Validation
const sleep = ms => new Promise(resolve => setTimeout(resolve, ms));

const validate = () =>
  sleep(300).then(() => {
    throw {
      zip: 'This field is required',
    };
  });

const isRequired = (message: any) => (value: any) =>
  Boolean(value) ? undefined : message;

const FieldLevelValidation = () => (
  <div>
    <h1>Pick a username</h1>
    <Formik
      validationSchema={Schema}
      validate={validate}
      initialValues={{
        username: '',
        email: '',
        zip: '',
      }}
      onSubmit={values => {
        sleep(500).then(() => {
          alert(JSON.stringify(values, null, 2));
        });
      }}
      render={() => (
        <Form>
          <label htmlFor="username">Username</label>
          <div>
            <Field
              name="username"
              validate={isRequired('This field is required')}
              type="text"
              placeholder="username"
            />
            <ErrorMessage name="username" />
          </div>
          <br />
          <div>
            <Field
              name="email"
              validate={isRequired('This field is required')}
              type="text"
              placeholder="email"
            />
            <ErrorMessage name="email" />
          </div>
          <br />
          <div>
            <Field
              name="zip"
              validate={isRequired('This field is required')}
              type="text"
              placeholder="zip"
            />
            <ErrorMessage name="zip" />
          </div>
          <br />
          <button type="submit">Submit</button>
          <Debug />
        </Form>
      )}
    />
  </div>
);

export default FieldLevelValidation;

==> examples-0.0.8.tgz: package/src/CombinedValidations.tsx <==
import * as React from 'react'
import {Formik, Field, Form, ErrorMessage} from 'formik'
import * as Yup from 'yup'
import Debug from './Debug'

const Schema = Yup.object().shape({
  email: Yup.string().required('This field is required'),
})

// Async Validation
const sleep = ms => new Promise(resolve => setTimeout(resolve, ms))

const validate = () =>
  sleep(300).then(() => {
    throw {
      zip: 'This field is required',
    }
  })

const isRequired = (message: any) => (value: any) =>
  Boolean(value) ? undefined : message

const FieldLevelValidation = () => (
  <div>
    <h1>Pick a username</h1>
    <Formik
      validationSchema={Schema}
      validate={validate}
      initialValues={{
        username: '',
        email: '',
        zip: '',
      }}
      onSubmit={values => {
        sleep(500).then(() => {
          alert(JSON.stringify(values, null, 2))
        })
      }}
      render={() => (
        <Form>
          <label htmlFor="username">Username</label>
          <div>
            <Field
              name="username"
              validate={isRequired('This field is required')}
              type="text"
              placeholder="username"
            />
            <ErrorMessage name="username" />
          </div>
          <br />
          <div>
            <Field
              name="email"
              validate={isRequired('This field is required')}
              type="text"
              placeholder="email"
            />
            <ErrorMessage name="email" />
          </div>
          <br />
          <div>
            <Field
              name="zip"
              validate={isRequired('This field is required')}
              type="text"
              placeholder="zip"
            />
            <ErrorMessage name="zip" />
          </div>
          <br />
          <button type="submit">Submit</button>
          <Debug />
        </Form>
      )}
    />
  </div>
)

export default FieldLevelValidation
